@@ -865,22 +865,24 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
 
     def pause_consume(self):
         """设置队列为暂停消费状态"""
-        RedisMixin().redis_db_frame.set(self._redis_key_pause_flag, 1)
+        self._stop_flag = 1
+        self.logger.info("==========停止消费===========")
+        #RedisMixin().redis_db_frame.set(self._redis_key_pause_flag, 1)
 
     def continue_consume(self):
         """设置队列为继续消费状态"""
         RedisMixin().redis_db_frame.set(self._redis_key_pause_flag, 0)
 
     def _submit_task(self, kw):
-        while 1:  # 这一块的代码为支持暂停消费。
-            # print(self._pause_flag)
-            if self._pause_flag == 1:
-                time.sleep(1)
-                if time.time() - self._last_show_pause_log_time > 60:
-                    self.logger.warning(f'已设置 {self.queue_name} 队列中的任务为暂停消费')
-                    self._last_show_pause_log_time = time.time()
-            else:
-                break
+        # while 1:  # 这一块的代码为支持暂停消费。
+        #     # print(self._pause_flag)
+        #     if self._pause_flag == 1:
+        #         time.sleep(1)
+        #         if time.time() - self._last_show_pause_log_time > 60:
+        #             self.logger.warning(f'已设置 {self.queue_name} 队列中的任务为暂停消费')
+        #             self._last_show_pause_log_time = time.time()
+        #     else:
+        #         break
 
         if self._judge_is_daylight():
             self._requeue(kw)
@@ -1056,7 +1058,7 @@ class ConcurrentModeDispatcher(LoggerMixin):
         else:
             if self._concurrent_mode in [ConcurrentModeEnum.THREADING, ConcurrentModeEnum.ASYNC,
                                          ConcurrentModeEnum.SINGLE_THREAD, ]:
-                t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task))
+                t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task), daemon=True)
                 ConsumersManager.schedulal_thread_to_be_join.append(t)
                 t.start()
 
@@ -1157,17 +1159,18 @@ class DistributedConsumerStatistics(RedisMixin, LoggerMixinDefaultWithFileHandle
 
     # noinspection PyProtectedMember
     def _get_stop_and_pause_flag_from_redis(self):
-        stop_flag = self.redis_db_frame.get(self._consumer._redis_key_stop_flag)
-        if stop_flag is not None and int(stop_flag) == 1:
-            self._consumer._stop_flag = 1
-        else:
-            self._consumer._stop_flag = 0
-
-        pause_flag = self.redis_db_frame.get(self._consumer._redis_key_pause_flag)
-        if pause_flag is not None and int(pause_flag) == 1:
-            self._consumer._pause_flag = 1
-        else:
-            self._consumer._pause_flag = 0
+        return
+        # stop_flag = self.redis_db_frame.get(self._consumer._redis_key_stop_flag)
+        # if stop_flag is not None and int(stop_flag) == 1:
+        #     self._consumer._stop_flag = 1
+        # else:
+        #     self._consumer._stop_flag = 0
+        #
+        # pause_flag = self.redis_db_frame.get(self._consumer._redis_key_pause_flag)
+        # if pause_flag is not None and int(pause_flag) == 1:
+        #     self._consumer._pause_flag = 1
+        # else:
+        #     self._consumer._pause_flag = 0
 
 
 class ActiveCousumerProcessInfoGetter(RedisMixin, LoggerMixinDefaultWithFileHandler):
